@@ -1,3 +1,6 @@
+#ifndef lint
+static const char SCCSID[]="@(#)PJ_eck4.c	4.1	94/02/15	GIE	REL";
+#endif
 #define PJ_LIB__
 #include	<projects.h>
 PROJ_HEAD(eck4, "Eckert IV") "\n\tPCyl, Sph.";
@@ -35,9 +38,9 @@ FORWARD(s_forward); /* spheroid */
 INVERSE(s_inverse); /* spheroid */
 	double c;
 
-	lp.phi = aasin(P->ctx,xy.y / C_y);
+	lp.phi = aasin(xy.y / C_y);
 	lp.lam = xy.x / (C_x * (1. + (c = cos(lp.phi))));
-	lp.phi = aasin(P->ctx,(lp.phi + sin(lp.phi) * (c + 2.)) / C_p);
+	lp.phi = aasin((lp.phi + sin(lp.phi) * (c + 2.)) / C_p);
 	return (lp);
 }
 FREEUP; if (P) pj_dalloc(P); }
