@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id$
+ * $Id: cs2cs.c,v 1.10 2006/10/10 15:24:05 fwarmerdam Exp $
  *
  * Project:  PROJ.4
  * Purpose:  Mainline program sort of like ``proj'' for converting between
@@ -26,8 +26,40 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- *****************************************************************************/
-
+ ******************************************************************************
+ *
+ * $Log: cs2cs.c,v $
+ * Revision 1.10  2006/10/10 15:24:05  fwarmerdam
+ *  Increase MAX_LINE to 1000 per request from Dan Scheirer.
+ *
+ * Revision 1.9  2006/03/30 14:35:09  fwarmerdam
+ * bug 1145: avoid warnings on VC8.
+ *
+ * Revision 1.8  2004/10/28 16:05:37  fwarmerdam
+ * avoid using global variables from DLL
+ *
+ * Revision 1.7  2003/03/25 17:53:13  warmerda
+ * modified so that -f formats are used for Z as well
+ *
+ * Revision 1.6  2002/12/09 16:01:02  warmerda
+ * added prime meridian support
+ *
+ * Revision 1.5  2002/11/19 20:33:42  warmerda
+ * cleanup before exit to facilitate memory leak testing
+ *
+ * Revision 1.4  2001/04/05 19:32:19  warmerda
+ * use projPJ, and pj_is_latlong()
+ *
+ * Revision 1.3  2001/04/05 04:23:28  warmerda
+ * use pj_latlong_from_proj
+ *
+ * Revision 1.2  2001/02/03 18:36:55  warmerda
+ * removed some unavailable options from usage string
+ *
+ * Revision 1.1  2000/07/06 23:32:27  warmerda
+ * New
+ *
+ */
 #include "projects.h"
 #include <stdio.h>
 #include <stdlib.h>
@@ -116,7 +148,6 @@ static void process(FILE *fid)
             {
                 data.u = HUGE_VAL;
                 data.v = HUGE_VAL;
-                emess(-3,"pj_transform(): %s", pj_strerrno(pj_errno));
             }
         }
 
@@ -153,10 +184,7 @@ static void process(FILE *fid)
             printf( oform, z );
         else
             printf( "%.3f", z );
-        if( s )
-            printf( "%s", s );
-        else
-            printf( "\n" );
+        fputs("\n", stdout );
     }
 }
 
@@ -166,12 +194,13 @@ static void process(FILE *fid)
 
 int main(int argc, char **argv) 
 {
-    char *arg, **eargv = argv, *from_argv[MAX_PARGS], *to_argv[MAX_PARGS];
+    char *arg, **eargv = argv, *from_argv[MAX_PARGS], *to_argv[MAX_PARGS],
+        **iargv = argv;
     FILE *fid;
-    int from_argc=0, to_argc=0, eargc = 0, c, mon = 0;
+    int from_argc=0, to_argc=0, iargc = argc, eargc = 0, c, mon = 0;
     int have_to_flag = 0, inverse = 0, i;
 
-    if ((emess_dat.Prog_name = strrchr(*argv,DIR_CHAR)) != NULL)
+    if (emess_dat.Prog_name = strrchr(*argv,DIR_CHAR))
         ++emess_dat.Prog_name;
     else emess_dat.Prog_name = *argv;
     inverse = ! strncmp(emess_dat.Prog_name, "inv", 3);
@@ -283,10 +312,6 @@ int main(int argc, char **argv)
               case 's': /* reverse output */
                 reverseout = 1;
                 continue;
-              case 'd': /* set debug level */
-                if (--argc <= 0) goto noargument;
-                pj_ctx_set_debug( pj_get_default_ctx(), atoi(*++argv));
-                continue;
               default:
                 emess(1, "invalid option: -%c",*arg);
                 break;
@@ -339,11 +364,7 @@ int main(int argc, char **argv)
         to_argc = argcount;
     }
 
-    if( from_argc == 0 && to_argc != 0 )
-    {
-        /* we will generate the from proj as the latlong of the +to in a bit */
-    }
-    else if (!(fromProj = pj_init(from_argc, from_argv)))
+    if (!(fromProj = pj_init(from_argc, from_argv)))
     {
         printf( "Using from definition: " );
         for( i = 0; i < from_argc; i++ )
@@ -378,20 +399,6 @@ int main(int argc, char **argv)
               pj_strerrno(pj_errno));
     }
 
-    if( from_argc == 0 && toProj != NULL) 
-    {
-        if (!(fromProj = pj_latlong_from_proj( toProj )))
-        {
-            printf( "Using to definition: " );
-            for( i = 0; i < to_argc; i++ )
-                printf( "%s ", to_argv[i] );
-            printf( "\n" );
-            
-            emess(3,"projection initialization failure\ncause: %s",
-                  pj_strerrno(pj_errno));
-        }   
-    }
-
     if (mon) {
         printf( "%c ---- From Coordinate System ----\n", tag );
         pj_pr_list(fromProj);
