@@ -3,6 +3,15 @@
 static const char SCCSID[]="@(#)emess.c	4.6	94/05/24	GIE	REL";
 #endif
 
+#ifdef _MSC_VER
+#  ifndef _CRT_SECURE_NO_DEPRECATE
+#    define _CRT_SECURE_NO_DEPRECATE
+#  endif
+#  ifndef _CRT_NONSTDC_NO_DEPRECATE
+#    define _CRT_NONSTDC_NO_DEPRECATE
+#  endif
+#endif
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <stdarg.h>
@@ -18,7 +27,8 @@ emess(int code, char *fmt, ...) {
 	va_start(args, fmt);
 	/* prefix program name, if given */
 	if (fmt != NULL)
-		(void)fprintf(stderr,"%s\n<%s>: ",pj_release,emess_dat.Prog_name);
+		(void)fprintf(stderr,"%s\n<%s>: ",pj_get_release(),
+                              emess_dat.Prog_name);
 	/* print file name and line, if given */
 	if (emess_dat.File_name != NULL && *emess_dat.File_name) {
 		(void)fprintf(stderr,"while processing file: %s", emess_dat.File_name);
