@@ -2,11 +2,11 @@
 static const char SCCSID[]="@(#)geod.c	4.8	95/09/23	GIE	REL";
 #endif
 /* <<<< Geodesic filter program >>>> */
-# include <ctype.h>
-# include <stdio.h>
 # include "projects.h"
 # include "geodesic.h"
 # include "emess.h"
+# include <ctype.h>
+# include <stdio.h>
 # include <string.h>
 
 # define MAXLINE 200
@@ -138,7 +138,8 @@ int main(int argc, char **argv) {
 	else emess_dat.Prog_name = *argv;
 	inverse = ! strncmp(emess_dat.Prog_name, "inv", 3);
 	if (argc <= 1 ) {
-		(void)fprintf(stderr, usage, pj_release, emess_dat.Prog_name);
+		(void)fprintf(stderr, usage, pj_get_release(),
+                              emess_dat.Prog_name);
 		exit (0);
 	}
 		/* process run line arguments */
@@ -177,22 +178,20 @@ noargument:		   emess(1,"missing argument for -%c",*arg);
 				continue;
 			case 'l':
 				if (!arg[1] || arg[1] == 'e') { /* list of ellipsoids */
-					struct PJ_ELLPS *le;
-	
-					for (le = pj_ellps; le->id ; ++le)
-						(void)printf("%9s %-16s %-16s %s\n",
-						le->id, le->major, le->ell, le->name);
-				 		emess(1,"invalid list option: l%c",arg[1]);
-							emess(1,"-l[p|e] terminates program");
+                                    struct PJ_ELLPS *le;
+                                    
+                                    for (le=pj_get_ellps_ref(); le->id ; ++le)
+                                        (void)printf("%9s %-16s %-16s %s\n",
+                                                     le->id, le->major, le->ell, le->name);
 				} else if (arg[1] == 'u') { /* list of units */
-					struct PJ_UNITS *lu;
-
-					for (lu = pj_units; lu->id ; ++lu)
-						(void)printf("%12s %-20s %s\n",
-				 			lu->id, lu->to_meter, lu->name);
+                                    struct PJ_UNITS *lu;
+                                    
+                                    for (lu = pj_get_units_ref();lu->id ; ++lu)
+                                        (void)printf("%12s %-20s %s\n",
+                                                     lu->id, lu->to_meter, lu->name);
 				} else
-					emess(1,"invalid list option: l%c",arg[1]);
-				emess(1,"will not proceed after display list option");
+                                    emess(1,"invalid list option: l%c",arg[1]);
+                                exit( 0 );
 			case 'p': /* output azimuths as positive */
 				pos_azi = 1;
 				continue;
