@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id$
+ * $Id: pj_datum_set.c,v 1.4 2007/11/29 21:06:50 fwarmerdam Exp $
  *
  * Project:  PROJ.4
  * Purpose:  Apply datum definition to PJ structure from initialization string.
@@ -25,7 +25,22 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- *****************************************************************************/
+ ******************************************************************************
+ *
+ * $Log: pj_datum_set.c,v $
+ * Revision 1.4  2007/11/29 21:06:50  fwarmerdam
+ * make sure we only look for 7 parameters
+ *
+ * Revision 1.3  2007/01/31 06:41:01  fwarmerdam
+ * dont parse more datum parameters than we have room for in datum_params[]
+ *
+ * Revision 1.2  2001/04/04 21:13:21  warmerda
+ * do arcsecond/radian and ppm datum parm transformation in pj_set_datum()
+ *
+ * Revision 1.1  2000/07/06 23:32:27  warmerda
+ * New
+ *
+ */
 
 #include <projects.h>
 #include <string.h>
@@ -37,10 +52,10 @@
 /*                            pj_datum_set()                            */
 /************************************************************************/
 
-int pj_datum_set(projCtx ctx, paralist *pl, PJ *projdef)
+int pj_datum_set(paralist *pl, PJ *projdef)
 
 {
-    const char *name, *towgs84, *nadgrids, *catalog;
+    const char *name, *towgs84, *nadgrids;
 
     projdef->datum_type = PJD_UNKNOWN;
 
@@ -54,7 +69,7 @@ int pj_datum_set(projCtx ctx, paralist *pl, PJ *projdef)
 /*      definition will last into the pj_ell_set() function called      */
 /*      after this one.                                                 */
 /* -------------------------------------------------------------------- */
-    if( (name = pj_param(ctx, pl,"sdatum").s) != NULL )
+    if( (name = pj_param(pl,"sdatum").s) != NULL )
     {
         paralist *curr;
         const char *s;
@@ -66,7 +81,7 @@ int pj_datum_set(projCtx ctx, paralist *pl, PJ *projdef)
         /* find the datum definition */
         for (i = 0; (s = pj_datums[i].id) && strcmp(name, s) ; ++i) {}
 
-        if (!s) { pj_ctx_set_errno(ctx, -9); return 1; }
+        if (!s) { pj_errno = -9; return 1; }
 
         if( pj_datums[i].ellipse_id && strlen(pj_datums[i].ellipse_id) > 0 )
         {
@@ -84,7 +99,7 @@ int pj_datum_set(projCtx ctx, paralist *pl, PJ *projdef)
 /* -------------------------------------------------------------------- */
 /*      Check for nadgrids parameter.                                   */
 /* -------------------------------------------------------------------- */
-    if( (nadgrids = pj_param(ctx, pl,"snadgrids").s) != NULL )
+    if( (nadgrids = pj_param(pl,"snadgrids").s) != NULL )
     {
         /* We don't actually save the value separately.  It will continue
            to exist int he param list for use in pj_apply_gridshift.c */
@@ -92,25 +107,10 @@ int pj_datum_set(projCtx ctx, paralist *pl, PJ *projdef)
         projdef->datum_type = PJD_GRIDSHIFT;
     }
 
-/* -------------------------------------------------------------------- */
-/*      Check for grid catalog parameter, and optional date.            */
-/* -------------------------------------------------------------------- */
-    else if( (catalog = pj_param(ctx, pl,"scatalog").s) != NULL )
-    {
-        const char *date;
-
-        projdef->datum_type = PJD_GRIDSHIFT;
-        projdef->catalog_name = strdup(catalog);
-
-        date = pj_param(ctx, pl, "sdate").s;
-        if( date != NULL) 
-            projdef->datum_date = pj_gc_parsedate( ctx, date);
-    }
-
 /* -------------------------------------------------------------------- */
 /*      Check for towgs84 parameter.                                    */
 /* -------------------------------------------------------------------- */
-    else if( (towgs84 = pj_param(ctx, pl,"stowgs84").s) != NULL )
+    else if( (towgs84 = pj_param(pl,"stowgs84").s) != NULL )
     {
         int    parm_count = 0;
         const char *s;
