@@ -37,6 +37,7 @@ PROJ_HEAD(fouc, "Foucaut")
 PROJ_HEAD(fouc_s, "Foucaut Sinusoidal")
 PROJ_HEAD(gall, "Gall (Gall Stereographic)")
 PROJ_HEAD(geocent, "Geocentric")
+PROJ_HEAD(geos, "Geostationary Satellite View")
 PROJ_HEAD(gins8, "Ginsburg VIII (TsNIIGAiK)")
 PROJ_HEAD(gn_sinu, "General Sinusoidal Series")
 PROJ_HEAD(gnom, "Gnomonic")
@@ -54,8 +55,10 @@ PROJ_HEAD(laea, "Lambert Azimuthal Equal Area")
 PROJ_HEAD(lagrng, "Lagrange")
 PROJ_HEAD(larr, "Larrivee")
 PROJ_HEAD(lask, "Laskowski")
-PROJ_HEAD(latlong, "Lat/long (Geodetic)")
-PROJ_HEAD(longlat, "Lat/long (Geodetic)")
+PROJ_HEAD(lonlat, "Lat/long (Geodetic)")
+PROJ_HEAD(latlon, "Lat/long (Geodetic alias)")
+PROJ_HEAD(latlong, "Lat/long (Geodetic alias)")
+PROJ_HEAD(longlat, "Lat/long (Geodetic alias)")
 PROJ_HEAD(lcc, "Lambert Conformal Conic")
 PROJ_HEAD(lcca, "Lambert Conformal Conic Alternative")
 PROJ_HEAD(leac, "Lambert Equal Area Conic")
@@ -70,7 +73,6 @@ PROJ_HEAD(mbtfps, "McBryde-Thomas Flat-Polar Sinusoidal")
 PROJ_HEAD(merc, "Mercator")
 PROJ_HEAD(mil_os, "Miller Oblated Stereographic")
 PROJ_HEAD(mill, "Miller Cylindrical")
-PROJ_HEAD(mpoly, "Modified Polyconic")
 PROJ_HEAD(moll, "Mollweide")
 PROJ_HEAD(murd1, "Murdoch I")
 PROJ_HEAD(murd2, "Murdoch II")
@@ -99,10 +101,12 @@ PROJ_HEAD(putp6, "Putnins P6")
 PROJ_HEAD(putp6p, "Putnins P6'")
 PROJ_HEAD(qua_aut, "Quartic Authalic")
 PROJ_HEAD(robin, "Robinson")
+PROJ_HEAD(rouss, "Roussilhe Stereographic")
 PROJ_HEAD(rpoly, "Rectangular Polyconic")
 PROJ_HEAD(sinu, "Sinusoidal (Sanson-Flamsteed)")
 PROJ_HEAD(somerc, "Swiss. Obl. Mercator")
 PROJ_HEAD(stere, "Stereographic")
+PROJ_HEAD(sterea, "Oblique Stereographic Alternative")
 PROJ_HEAD(tcc, "Transverse Central Cylindrical")
 PROJ_HEAD(tcea, "Transverse Cylindrical Equal Area")
 PROJ_HEAD(tissot, "Tissot Conic")
