@@ -2,7 +2,7 @@
 
 #include <projects.h>
 
-char const pj_release[]="Rel. 4.9.1, 04 March 2015";
+char const pj_release[]="Rel. 4.6.0, 21 Dec 2007";
 
 const char *pj_get_release()
 
