@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id$
+ * $Id: proj_api.h,v 1.16 2007/11/29 21:07:49 fwarmerdam Exp $
  *
  * Project:  PROJ.4
  * Purpose:  Public (application) include file for PROJ.4 API, and constants.
@@ -25,7 +25,59 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- *****************************************************************************/
+ ******************************************************************************
+ *
+ * $Log: proj_api.h,v $
+ * Revision 1.16  2007/11/29 21:07:49  fwarmerdam
+ * prepare for 4.6.0 release
+ *
+ * Revision 1.15  2007/08/20 13:40:06  fwarmerdam
+ * avoid warnings in c++ for some prototypes
+ *
+ * Revision 1.14  2006/04/20 04:19:59  fwarmerdam
+ * updated version
+ *
+ * Revision 1.13  2004/10/30 02:33:47  fwarmerdam
+ * Updated release version.
+ *
+ * Revision 1.12  2004/09/16 15:14:01  fwarmerdam
+ * * src/pj_open_lib.c: added pj_set_searchpath() provided by Eric Miller.
+ *
+ * Revision 1.11  2004/07/28 23:23:49  warmerda
+ * Changed ra to es in declarations for pj_geocentric_to_geodetic()
+ * and pj_geodetic_to_geocentric() as suggested by Britton Kerin.
+ *
+ * Revision 1.10  2004/05/04 03:28:01  warmerda
+ * Updated version.
+ *
+ * Revision 1.9  2004/04/15 13:56:24  warmerda
+ * added pj_get_release
+ *
+ * Revision 1.8  2003/03/31 14:52:38  warmerda
+ * updated to 4.4.7
+ *
+ * Revision 1.7  2002/12/14 20:14:35  warmerda
+ * added geocentric support
+ *
+ * Revision 1.6  2002/06/11 18:08:25  warmerda
+ * Added the pj_get_def() function
+ *
+ * Revision 1.5  2002/01/09 14:36:22  warmerda
+ * updated to 4.4.5
+ *
+ * Revision 1.4  2001/09/15 22:55:28  warmerda
+ * final prep for 4.4.4 release
+ *
+ * Revision 1.3  2001/08/23 20:25:55  warmerda
+ * added pj_set_finder function
+ *
+ * Revision 1.2  2001/06/02 03:35:36  warmerda
+ * added pj_get_errno_ref()
+ *
+ * Revision 1.1  2001/04/06 01:24:22  warmerda
+ * New
+ *
+ */
 
 /* General projections header file */
 #ifndef PROJ_API_H
@@ -40,7 +92,7 @@ extern "C" {
 #endif
 
 /* Try to update this every version! */
-#define PJ_VERSION 491
+#define PJ_VERSION 460
 
 extern char const pj_release[]; /* global release id string */
 
@@ -55,24 +107,12 @@ extern int pj_errno;	/* global error return code */
     typedef void *projPJ;
     #define projXY projUV
     #define projLP projUV
-    typedef void *projCtx;
 #else
     typedef PJ *projPJ;
-    typedef projCtx_t *projCtx;
 #   define projXY	XY
 #   define projLP       LP
 #endif
 
-/* file reading api, like stdio */
-typedef int *PAFile;
-typedef struct projFileAPI_t {
-    PAFile  (*FOpen)(projCtx ctx, const char *filename, const char *access);
-    size_t  (*FRead)(void *buffer, size_t size, size_t nmemb, PAFile file);
-    int     (*FSeek)(PAFile file, long offset, int whence);
-    long    (*FTell)(PAFile file);
-    void    (*FClose)(PAFile);
-} projFileAPI;
-
 /* procedure prototypes */
 
 projXY pj_fwd(projLP, projPJ);
@@ -89,22 +129,18 @@ int pj_geodetic_to_geocentric( double a, double es,
                                long point_count, int point_offset,
                                double *x, double *y, double *z );
 int pj_compare_datums( projPJ srcdefn, projPJ dstdefn );
-int pj_apply_gridshift( projCtx, const char *, int, 
+int pj_apply_gridshift( const char *, int, 
                         long point_count, int point_offset,
                         double *x, double *y, double *z );
 void pj_deallocate_grids(void);
-void pj_clear_initcache(void);
 int pj_is_latlong(projPJ);
 int pj_is_geocent(projPJ);
-void pj_get_spheroid_defn(projPJ defn, double *major_axis, double *eccentricity_squared);
 void pj_pr_list(projPJ);
 void pj_free(projPJ);
 void pj_set_finder( const char *(*)(const char *) );
 void pj_set_searchpath ( int count, const char **path );
 projPJ pj_init(int, char **);
 projPJ pj_init_plus(const char *);
-projPJ pj_init_ctx( projCtx, int, char ** );
-projPJ pj_init_plus_ctx( projCtx, const char * );
 char *pj_get_def(projPJ, int);
 projPJ pj_latlong_from_proj( projPJ );
 void *pj_malloc(size_t);
@@ -112,43 +148,6 @@ void pj_dalloc(void *);
 char *pj_strerrno(int);
 int *pj_get_errno_ref(void);
 const char *pj_get_release(void);
-void pj_acquire_lock(void);
-void pj_release_lock(void);
-void pj_cleanup_lock(void);
-
-projCtx pj_get_default_ctx(void);
-projCtx pj_get_ctx( projPJ );
-void pj_set_ctx( projPJ, projCtx );
-projCtx pj_ctx_alloc(void);
-void    pj_ctx_free( projCtx );
-int pj_ctx_get_errno( projCtx );
-void pj_ctx_set_errno( projCtx, int );
-void pj_ctx_set_debug( projCtx, int );
-void pj_ctx_set_logger( projCtx, void (*)(void *, int, const char *) );
-void pj_ctx_set_app_data( projCtx, void * );
-void *pj_ctx_get_app_data( projCtx );
-void pj_ctx_set_fileapi( projCtx, projFileAPI *);
-projFileAPI *pj_ctx_get_fileapi( projCtx );
-
-void pj_log( projCtx ctx, int level, const char *fmt, ... );
-void pj_stderr_logger( void *, int, const char * );
-
-/* file api */
-projFileAPI *pj_get_default_fileapi();
-
-PAFile pj_ctx_fopen(projCtx ctx, const char *filename, const char *access);
-size_t pj_ctx_fread(projCtx ctx, void *buffer, size_t size, size_t nmemb, PAFile file);
-int    pj_ctx_fseek(projCtx ctx, PAFile file, long offset, int whence);
-long   pj_ctx_ftell(projCtx ctx, PAFile file);
-void   pj_ctx_fclose(projCtx ctx, PAFile file);
-char  *pj_ctx_fgets(projCtx ctx, char *line, int size, PAFile file);
-
-PAFile pj_open_lib(projCtx, const char *, const char *);
-
-#define PJ_LOG_NONE        0
-#define PJ_LOG_ERROR       1
-#define PJ_LOG_DEBUG_MAJOR 2
-#define PJ_LOG_DEBUG_MINOR 3
 
 #ifdef __cplusplus
 }
